Installing NanoSpell Spellchecker for TinyMCE - Step By Step Helper

# nanospell

## TinyMCE Spellchecking Plugin Installation Helper

This page helps you to ensure that NanoSpell is set-up correctly, de-bugs issues before they arise, and provides customized code samples.

Run The Test »

This page needs to be running while you are connected to the internet. Please connect to the internet and re-run the test.

Your data is never sent to other servers, but we need to load jQuery and Bootstrap libraries from CDN servers to keep the installer package small and lightweight.

For this software to run, it needs to be located on a web server using http:// or https:// protocols.

Currently you are viewing this page using the file:// protocol. When your site is running on a web-server, testing server or localhost - please re-run this page.

Please select 1 of the 4 server languages which nanospell supports (in the tabs below to the left) - and read the personalized installation guide.

## Setup NanoSpell using PHP

This option will instruct NanoSpell to use PHP to perform all of the TinyMCE spellchecking operations.

#### Live Example using PHP

Helllo Worlb! PHP is working!

#### Example Code

Use javascript code like this when initializing TinyMCE within your pages to add the spellchecker.

    tinymce.init({
     selector:'textarea',
     external_plugins: { "nanospell": "path/to/nanospell/plugin.js" },
     nanospell_server:"php"
    });

Read more about NanoSpell settings and dictionaries

## Setup NanoSpell using ASP.Net or Mono

This option will instruct NanoSpell to use ASP.Net to perform all of the TinyMCE spellchecking operations.

#### Live Example using ASP.Net

Helllo Worlb! ASP.Net is working!

#### Example Code

Use javascript code like this when initializing TinyMCE within your pages to add the spellchecker.

    tinymce.init({
    	selector:'textarea',
    	external_plugins: { "nanospell": "path/to/nanospell/plugin.js" },
    	nanospell_server:"asp.net"
    });

Read more about NanoSpell settings and dictionaries

## Setup NanoSpell using ASP VBScript

This option will instruct NanoSpell to use Microsoft Active Server Pages to perform all of the TinyMCE spellchecking operations. If ASP.net is an option for you - we always recommend ASP.net over classic asp because it is a faster, more stable language.

#### Live Example using ASP

Helllo Worlb! ASP Vbscript is working!

#### Example Code

Use javascript code like this when initializing TinyMCE within your pages to add the spellchecker.

    tinymce.init({
    	selector:'textarea',
    	external_plugins: { "nanospell": "path/to/nanospell/plugin.js" },
    	nanospell_server:"asp"
    });

Read more about NanoSpell settings and dictionaries

## Setup NanoSpell using Java

To install this software on a Java based server we recommend installing the java-php bridge. http://php-java-bridge.sourceforge.net/pjb/

You may then use the "php" server language to run nanospell.